@@ -129,8 +129,8 @@ removeWords.PlainTextDocument <- function(x, words)
 stemDocument <- function(x, language = "english") UseMethod("stemDocument", x)
 stemDocument.character <- function(x, language = "english")
     Snowball::SnowballStemmer(x, RWeka::Weka_control(S = language))
-stemDocument.PlainTextDocument <- function(x, language = "english") {
-    s <- unlist(lapply(x, function(x) paste(stemDocument.character(unlist(strsplit(x, "[[:blank:]]"))), collapse = " ")))
+stemDocument.PlainTextDocument <- function(x, language = map_IETF(Language(x))) {
+    s <- unlist(lapply(x, function(x) paste(stemDocument.character(unlist(strsplit(x, "[[:blank:]]")), language), collapse = " ")))
     Content(x) <- if (is.character(s)) s else ""
     x
 }
